@@ -1,6 +1,7 @@
 package t::Ball;
 
-use strict;
+use v5.14;
+use warnings;
 
 use base qw( Tangence::Object t::Colourable );
 
@@ -36,4 +37,4 @@ sub method_bounce
    return "bouncing";
 }
 
-1;
+0x55AA;
